@@ -70,7 +70,7 @@ use strict;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.02';
+	$VERSION = '2.04';
 }
 
 # No longer allow direct access to the array
@@ -150,7 +150,7 @@ sub clear {
 
 All bugs should be filed via the CPAN bug tracker at
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-Send>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-Send-Test>
 
 For other issues, or commercial enhancement or support, contact the author.
 
@@ -160,7 +160,7 @@ Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 - 2006 Adam Kennedy. All rights reserved.
+Copyright (c) 2004 - 2005 Adam Kennedy. All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
